import IMask from 'imask';
import { twMoment as moment } from './custom-moment.js'

export const initMaskDateUISetting = () => {
    // 初始化時間日期遮罩元件
    const dateTimeMaskUIList = document.querySelectorAll("input[data-toggle='neo-datetime'][data-is-tw='False']");
    const twDateTeimMaskUIList = document.querySelectorAll("input[data-toggle='neo-datetime'][data-is-tw='True']");
    for (var i = 0; i < dateTimeMaskUIList.length; i++) {
        let imaskMin = null;
        let imaskMax = null;
        let momentFormat;
        // 轉換moment.js時間資料格式
        var serverSideMomentFormat = dateTimeMaskUIList[i].getAttribute("data-mask").split(' ');
        if (serverSideMomentFormat[0] === 'HH:mm') {
            // 取出可輸入的最小時間
            const dataMin = dateTimeMaskUIList[i].getAttribute("data-min")
            if (dataMin != null) {

                imaskMin = moment(dataMin, 'HH:mm').toDate()
                console.log(imaskMin)
            }
            // 取出可輸入的最大時間
            const dataMax = dateTimeMaskUIList[i].getAttribute("data-max")
            if (dataMax != null) {
                imaskMax = moment(dataMax, 'HH:mm').toDate()
                console.log(imaskMax)
            }
            momentFormat = serverSideMomentFormat[0];
        } else {
            const sDateFormat = serverSideMomentFormat[0].toUpperCase();
            let stimeFormat = '';
            if (serverSideMomentFormat.length > 1) {
                stimeFormat = ` ${serverSideMomentFormat[1]}`;
            }
            momentFormat = `${sDateFormat}${stimeFormat}` //'YYYY/MM/DD HH:mm';

            // 取出可輸入的最小日期
            const dataMin = dateTimeMaskUIList[i].getAttribute("data-min")
            if (dataMin != null) {
                imaskMin = moment(dateTimeMaskUIList[i].getAttribute("data-min"), momentFormat).toDate()
                console.log(imaskMin)
            }
            // 取出可輸入的最大日期
            const dataMax = dateTimeMaskUIList[i].getAttribute("data-max")
            if (dataMax != null) {
                imaskMax = moment(dateTimeMaskUIList[i].getAttribute("data-max"), momentFormat).toDate()

            }
        }

        IMask(dateTimeMaskUIList[i], {
            mask: Date,
            pattern: momentFormat,
            lazy: true,
            format: function (date) {
                return moment(date).format(momentFormat);
            },
            parse: function (str) {
                console.log(str)
                return moment(str, momentFormat);
            },

            blocks: {
                YYYY: {
                    mask: IMask.MaskedRange,
                    from: 1911,
                    to: 3000
                },
                MM: {
                    mask: IMask.MaskedRange,
                    from: 1,
                    to: 12
                },
                DD: {
                    mask: IMask.MaskedRange,
                    from: 1,
                    to: 31
                },
                HH: {
                    mask: IMask.MaskedRange,
                    from: 0,
                    to: 23
                },
                mm: {
                    mask: IMask.MaskedRange,
                    from: 0,
                    to: 59
                },
                ss: {
                    mask: IMask.MaskedRange,
                    from: 0,
                    to: 59
                }
            }
        });
    }
    // 初始化民國時間日期遮罩元件
    for (var i = 0; i < twDateTeimMaskUIList.length; i++) {
        const twDateTimePatern = twDateTeimMaskUIList[i].getAttribute("data-mask")
        const mask = IMask(twDateTeimMaskUIList[i], {
            // pattern: twDateTimePatern,
            // format: function (date) {
            //     console.log(date)
            //     return moment(date).format(twDateTimePatern);
            // },
            // parse: function (str) {
            //     console.log(str)
            //     return moment(str, twDateTimePatern);
            // },
            mask: twDateTimePatern,
            lazy: true,
            blocks: {
                tYY: {
                    mask: IMask.MaskedRange,
                    from: 1,
                    to: 999
                },
                MM: {
                    mask: IMask.MaskedRange,
                    from: 1,
                    to: 12
                },
                DD: {
                    mask: IMask.MaskedRange,
                    from: 1,
                    to: 31
                },
                HH: {
                    mask: IMask.MaskedRange,
                    from: 0,
                    to: 23
                },
                mm: {
                    mask: IMask.MaskedRange,
                    from: 0,
                    to: 59
                },
                ss: {
                    mask: IMask.MaskedRange,
                    from: 0,
                    to: 59
                }
            },
        })
        mask.on("accept", function () {
            try {
                if (mask.value.length >= 9) {
                    const currentDate = moment(mask.value, 'tYY/MM/DD');
                    if (!currentDate.isValid()) {
                        mask.value = mask.value.slice(0, -1);
                        console.log('不符合民國年格式')
                    }
                }
            } catch (error) {}
        });

    }
}
export const momentWithTW = moment;